gpsinfo

package module
v0.1.28 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: BSD-3-Clause Imports: 14 Imported by: 0

README

OVERVIEW

Go Reference Go Report Card Go Build

paepcke.de/gpsinfo

  • needs go1.20rc (sorry!)
  • Show and decode nmea frames from an (usb) gps dongle.
  • Focus on small embedded systems (debugging) on restricted resources.
  • Focus on power saving parser (NO CLEAN idomatic go code for hot loop, no clean full state maschine, quick hack)
  • 100 % pure go, stdlib only, no external dependencies, use as app or api (see api.go)

INSTALL

go install paepcke.de/gpsinfo/cmd/gpsinfo@latest
DOWNLOAD (prebuild)

github.com/paepckehh/gpsinfo/releases

SHOWTIME

gpsinfo /dev/gps0
[...]

DOCS

pkg.go.dev/paepcke.de/gpsinfo

CONTRIBUTION

Yes, Please! PRs Welcome!

Documentation

Overview

package gpsinfo decodes gps nmea frames from your gpsdongle (debug/ingo)

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Debug

func Debug(device string)

Debug ...

func DebugD

func DebugD(dev *gpsfeed.GpsDevice)

DebugD ...

Types

This section is empty.

Directories

Path Synopsis
cmd
gpsinfo command
package main
package main
package geohash ..
package geohash ..
package gpsfeed
package gpsfeed
cmd/gpsfeed command
package nmeanano ...
package nmeanano ...
package zlatlong ...
package zlatlong ...

Jump to